@@ -22,10 +22,17 @@ class DTParttern(object):
         self._rules = rules
         self._parser = parser
         self.data_callback = callback
+        self._pre_code = None
+
+    def pre_code(self,code):
+        self._pre_code = code
 
     def _set_data(self,data):
         if isinstance(data,bytes):
-            data = data.decode('utf-8','ignore')
+            if self._pre_code=="utf-8" or self._pre_code==None:
+                data = data.decode('utf-8','ignore')
+            elif self._pre_code=="16bit":
+                data = data.hex().upper()
         self._data = data
 
     def _rule_right(self):
