@@ -4,15 +4,29 @@
 # @Author: SHAW
 # @QQ:838705177
 # -----------------------
+import json
+from datetime import datetime
+from urllib.parse import urlencode
+
+from tornado.httpclient import HTTPRequest, AsyncHTTPClient
 from tornado.options import options
 from tornado.ioloop import IOLoop
 import logging
 
-from config import *
+from addon import TcpDataTrans
 from server import DTCloudTcpServer
+from config import *
 from tools import init_logging
 from dtee_script.dtee_main import dtparsermanager
 
+
+async def pre_parse(data):
+    '''数据接收到之后，解析之前，处理方式'''
+    TcpDataTrans(data,('127.0.0.1',8076))  # 数据转发
+    return data
+
+dtparsermanager.add_pre_callback(pre_parse)
+
 async def handle_data(data):
     '''manager callback'''
     print("handle_data data:",data)
